@@ -81,31 +81,33 @@ class FilterTvdb(object):
             - John Terlesky
     """
 
-    def validator(self):
-        """Validate given configuration"""
-        from flexget import validator
-        thetvdb = validator.factory('dict')
-        thetvdb.accept('number', key='min_series_rating')
-        thetvdb.accept('number', key='min_episode_rating')
-        thetvdb.accept('integer', key='min_episode_air_year')
-        thetvdb.accept('integer', key='max_episode_air_year')
-        thetvdb.accept('number', key='min_episode_runtime')
-        thetvdb.accept('number', key='max_episode_runtime')
-        thetvdb.accept('list', key='reject_content_rating').accept('text')
-        thetvdb.accept('list', key='accept_content_rating').accept('text')
-        thetvdb.accept('list', key='accept_network').accept('text')
-        thetvdb.accept('list', key='reject_network').accept('text')
-        thetvdb.accept('list', key='reject_genres').accept('text')
-        thetvdb.accept('list', key='reject_status').accept('text')
-        thetvdb.accept('list', key='reject_languages').accept('text')
-        thetvdb.accept('list', key='accept_languages').accept('text')
-        thetvdb.accept('list', key='accept_actors').accept('text')
-        thetvdb.accept('list', key='reject_actors').accept('text')
-        thetvdb.accept('list', key='accept_writers').accept('text')
-        thetvdb.accept('list', key='reject_writers').accept('text')
-        thetvdb.accept('list', key='accept_directors').accept('text')
-        thetvdb.accept('list', key='reject_directors').accept('text')
-        return thetvdb
+    schema = {
+        'type': 'object',
+        'properties': {
+            'min_series_rating': {'type': 'number'},
+            'min_episode_rating': {'type': 'number'},
+            'min_episode_air_year': {'type': 'integer'},
+            'max_episode_air_year': {'type': 'integer'},
+            'min_episode_runtime': {'type': 'number'},
+            'max_episode_runtime': {'type': 'number'},
+            'reject_content_rating': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_content_rating': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_network': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_network': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_genres': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_status': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_languages': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_languages': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_actors': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_actors': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_writers': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_writers': {'type': 'array', 'items': {'type': 'string'}},
+            'accept_directors': {'type': 'array', 'items': {'type': 'string'}},
+            'reject_directors': {'type': 'array', 'items': {'type': 'string'}},
+
+        },
+        'additionalProperties': False
+    }
 
     def is_in_set(self, config, configkey, entryitem,):
         '''
